@@ -280,7 +280,7 @@ S3VNopAllCmdSets(ScrnInfoPtr pScrn)
 }
 
 void
-S3VGEReset(ScrnInfoPtr pScrn, int from_timeout, int line, char *file)
+S3VGEReset(ScrnInfoPtr pScrn, int from_timeout, int line, const char *file)
 {
     unsigned long gs1, gs2;   /* -- debug info for graphics state -- */
     unsigned char tmp, sr1, resetidx=0x66;  /* FIXME */
@@ -465,7 +465,7 @@ S3VAccelSync(ScrnInfoPtr pScrn)
     WAITIDLE();
 }
 
-
+#ifdef HAVE_XAA_H
 static void
 S3VEngineReset(ScrnInfoPtr pScrn)
 {
@@ -540,7 +540,6 @@ S3VWriteMask(
    return;
 }
 
-#ifdef HAVE_XAA_H
 
 	/************************\
 	|  Solid Filled Rects    |
